@@ -30,17 +30,4 @@ def duplicate(obj, changes=None):
     return duplicate
 
 
-def get_model_from_path_string(root_model, path):
-    """ Return a model class for a related model
-    root_model is the class of the initial model
-    path is like foo__bar where bar is related to foo
-    """
-    for path_section in path.split('__'):
-        if path_section:
-            field = root_model._meta.get_field_by_name(path_section)
-            if field[2]:
-                root_model = field[0].related.parent_model()
-            else:
-                root_model = field[0].model
-    return root_model
     
\ No newline at end of file
